@@ -236,7 +236,12 @@ output if the Pod source does not correspond to strict guidelines.
 The (optional) link to a style sheet, which is included in the resulting HTML
 as
 
-  <LINK TYPE="text/css" HREF=$link>
+  <LINK TYPE="text/css" REL="stylesheet" HREF=$link>
+
+=item B<-banner> I<bool>
+
+If true, a banner is included at the bottom of the generated
+page. Default is true.
 
 =back
 
@@ -253,7 +258,7 @@ use Pod::Checker;
 use HTML::Entities;
 use HTML::TreeBuilder;
 
-$VERSION = '0.48';
+$VERSION = '0.49';
 @ISA = qw(Exporter Pod::Parser);
 
 @EXPORT = qw();
@@ -312,8 +317,8 @@ sub pod2html {
     _default(\%opts, '-warnings', 0);
     _default(\%opts, '-verbose', 0);
     _default(\%opts, '-stylesheet', '');
+    _default(\%opts, '-banner', 1);
     _default(\%opts, '-idxopt', 'item,x');
-
     # only a single file?
     if($opts{-filter}) {
         $opts{-toc} = $opts{-idx} = 0;
@@ -327,7 +332,7 @@ sub pod2html {
     ###################################################
 
     my $cache = Pod::Cache->new();
-    foreach my $infile (keys %PODS) {
+    foreach my $infile (sort keys %PODS) {
         warn "\n+++ Scanning $infile\n" if($opts{-verbose});
         ## Now create a pod scanner, based on Pod::Checker
         my $scanner = Pod::Checker->new(-warnings => $opts{'-warnings'},
@@ -339,7 +344,8 @@ sub pod2html {
         ## Return the number of errors found
         my $errs = $scanner->num_errors();
         if($errs == -1) {
-            warn "Warning: No POD in `$infile', skipping\n";
+            warn "Warning: No POD in `$infile', skipping\n"
+              if($opts{'-warnings'});
             next;
         }
         elsif($errs > 0) {
@@ -401,7 +407,7 @@ sub pod2html {
     # propagate some of the options
     my %conv_opts;
     for(qw(-suffix -navigation -localtoc -toc -tocname -toctitle -idx
-        -idxname -idxtitle -idxopt -stylesheet -verbose)) {
+        -idxname -idxtitle -idxopt -stylesheet -verbose -banner)) {
         $conv_opts{$_} = $opts{$_};
     }
     
@@ -729,7 +735,7 @@ sub customize {
     # include stylesheet
     if($self->{-stylesheet}) {
       my $css = HTML::Element->new('link', TYPE => "text/css", 
-        HREF => $self->{-stylesheet});
+        REL => "stylesheet", HREF => $self->{-stylesheet});
       $self->{_head}->push_content($css, "\n");
     }
 
@@ -808,8 +814,9 @@ sub customize {
     $anchor = HTML::Element->new('a', CLASS => 'POD_NAVLINK',
         href => '#Pod_TOP_OF_PAGE');
     $anchor->push_content('[Top]');
-    $self->{_body}->push_content(HTML::Element->new('hr'), "\n", $anchor,
-        " \nGenerated by Marek::Pod::HTML $VERSION on " . localtime() . "\n");
+    $self->{_body}->push_content(HTML::Element->new('hr'), "\n", $anchor, "\n");
+    $self->{_body}->push_content("Generated by Marek::Pod::HTML $VERSION on " . localtime() . "\n")
+      if($self->{-banner});
 }
 
 =item depth()
@@ -1713,7 +1720,7 @@ L<HTML::Tagset>, L<pod2man>, L<pod2text>, L<Pod::Man>
 
 =head1 AUTHOR
 
-Marek Rouchal E<lt>marekr@cpan.org<gt>
+Marek Rouchal E<lt>marekr@cpan.orgE<gt>
 
 =head1 HISTORY
 
